django-jsanctions
=================

Parses and imports EU combined sanction lists for Django projects.

## Data Sources

* http://data.europa.eu/euodp/en/data/dataset/consolidated-list-of-persons-groups-and-entities-subject-to-eu-financial-sanctions
